Learn R Programming

cgal4h (version 0.1.0)

cgal4h-package: Provides the 'C++' header-only library of CGAL version 4

Description

'CGAL' is a C++ library that aims to provide easy access to efficient and reliable algorithms in computational geometry. Since its version 4, 'CGAL' can be used as standalone header-only library and is available under a double GPL-3|LGPL license. <https://www.cgal.org/>.

Arguments

See Also

Useful links:

Examples

Run this code
# NOT RUN {
# Include a dependency to cgal4h inside a cpp file
// [[Rcpp::depends(cgal4h)]]
include <Rcpp.h>
# }

Run the code above in your browser using DataLab